@@ -1,5 +1,5 @@
 import logging
-from typing import Any
+from typing import Any, Type
 
 from asgiref.sync import sync_to_async
 from django.db import models
@@ -10,21 +10,21 @@ logger = logging.getLogger(__name__)
 
 
 class CrudService(CrudModel):
-    def __init__(self, model: models.Model):
+    def __init__(self, model: Type[models.Model]):
         super().__init__(model)
         self.model = model
 
-    async def get_obj(self, id: int) -> Any:
-        return await sync_to_async(self._crud_get_obj)(id)
+    async def get_obj(self, pk: int) -> Any:
+        return await sync_to_async(self._crud_get_obj)(pk)
 
     async def get_objs(self, maximum: int = None, **filters: Any) -> Any:
         return await sync_to_async(self._crud_get_objs_all)(maximum, **filters)
 
-    async def patch_obj(self, id: int, payload: Any) -> Any:
-        return await sync_to_async(self._crud_update_obj)(id, payload)
+    async def patch_obj(self, pk: int, payload: Any) -> Any:
+        return await sync_to_async(self._crud_update_obj)(pk, payload)
 
-    async def del_obj(self, id: int) -> Any:
-        return await sync_to_async(self._crud_del_obj)(id)
+    async def del_obj(self, pk: int) -> Any:
+        return await sync_to_async(self._crud_del_obj)(pk)
 
     async def add_obj(self, **payload: Any) -> Any:
         return await sync_to_async(self._crud_add_obj)(**payload)
