@@ -14,6 +14,8 @@ class Category(TestBaseModel):
 class Client(TestBaseModel):
     key = models.CharField(max_length=20, unique=True)
     name = models.CharField(max_length=50, null=True)
+    category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True)
+    password = models.CharField(max_length=30, null=True)
 
 
 class Type(TestBaseModel):
@@ -35,6 +37,8 @@ class Event(TestBaseModel):
 
     owner = models.ManyToManyField(to=Client, related_name="events", null=True)
 
+    lead_owner = models.ManyToManyField(to=Client, related_name="lead_owner", null=True)
+
     type = models.ForeignKey(Type, on_delete=models.CASCADE, null=True)
 
     def __str__(self):
